==> humhub-1.15.3.tar.gz: humhub-1.15.3/protected/humhub/modules/space/messages/ru/manage.php <==
<?php
return array (
  '-' => '-',
  '<strong>Create</strong> Space' => '<strong>Создать</strong> новое сообщество',
  '<strong>Manage</strong> members' => '<strong>Управление</strong> пользователями',
  '<strong>Members</strong>' => '<strong>Участники</strong>',
  '<strong>Security</strong> settings' => '<strong>Настройки</strong> безопасности',
  '<strong>Space</strong> Modules' => '<strong>Модули</strong> сообщества',
  '<strong>Space</strong> settings' => '<strong>Настройки</strong> сообщества',
  'Actions' => 'Действия',
  'Activate' => 'Активировать',
  'Add <strong>Modules</strong>' => '<strong>Добавить</strong> модули',
  'Advanced access settings' => 'Расширенные настройки доступа',
  'All members excluding moderators and administrators of this Space will be removed. All pending invitations and membership requests will be terminated.' => 'Все участники, за исключением модераторов и администраторов этого сообщества, будут удалены. Все ожидающие приглашения и запросы на членство будут аннулированы.',
  'Archive' => 'Архив',
  'Are you sure you want to remove this member.' => 'Вы уверены, что хотите удалить этого участника?',
  'Are you sure, that you want to delete this space? All published content will be removed!' => 'Вы уверены, что хотите удалить это сообщество? Все опубликованные материалы будут удалены!',
  'As owner of this space you can transfer this role to another administrator in space.' => 'Вы, как владелец этого сообщества, можете передать эту роль другому администратору в сообществе.',
  'Cancel Membership' => 'Отменить участие',
  'Choose if new content should be public or private by default' => 'Выберите, будет новый контент по умолчанию публичным или приватным',
  'Choose the kind of membership you want to provide for this workspace.' => 'Выберите вид членства, которое Вы хотите использовать для этого рабочего сообщества.',
  'Choose the modules you want to use for this Space. If you are undecided, you can also activate them later on via the Space settings.' => 'Выберите модули, которые вы хотите использовать для этого сообщества. Если вы не определились, вы также можете активировать их позже через настройки сообщества.',
  'Choose the modules you want to use for this Space. In order for the modules to be available to you here, they must have been previously installed by administrators of the network using the admin panel. If you cannot deactivate individual modules, it is because they have been set as the default for the entire network.' => 'Выберите модули, которые вы хотите использовать для этого сообщества. Для того, чтобы модули были доступны вам здесь, они должны быть предварительно установлены администраторами сети с помощью админ-панели. Если вы не можете деактивировать отдельные модули, это связано с тем, что они установлены по умолчанию для всей сети.',
  'Choose the security level for this workspace to define the visibleness.' => 'Выберите уровень безопасности для этого рабочего сообщества, чтобы определить его видимость.',
  'Currently there are no modules available for this space!' => 'В настоящее время нет доступных модулей для этого сообщества!',
  'Delete' => 'Удалить',
  'Don\'t receive notifications for new content' => 'Не получать уведомления о новом контенте',
  'Hide posts on dashboard' => 'Скрывать записи',
  'Invited By' => 'Приглашён',
  'Members' => 'Участники',
  'Modules' => 'Модули',
  'Next' => 'Далее',
  'Only global administrators can change this value' => 'Только глобальные администраторы могут изменить это значение.',
  'Owner' => 'Владелец',
  'Pending Approvals' => 'Ожидающие подтверждения',
  'Pending Invites' => 'Ожидающие приглашения',
  'Permissions are assigned to different user-roles. To edit a permission, select the user-role you want to edit and change the drop-down value of the given permission.' => 'Права назначаются разным ролям пользователей. Чтобы редактировать права, выберите роль пользователя, которую Вы хотите редактировать, и измените его значение в раскрывающемся меню.',
  'Please type the name of the space to proceed.' => 'Пожалуйста, введите название сообщества, чтобы продолжить.',
  'Receive Notifications for new content' => 'Получать уведомления',
  'Removal of members queued' => 'Удаление участников из очереди',
  'Remove all members' => 'Удалить всех участников',
  'Remove from space' => 'Удалить из сообщества',
  'Role' => 'Роль',
  'Security' => 'Безопасность',
  'Show all' => 'Показать все',
  'Show posts on dashboard' => 'Показывать записи в панели «События»',
  'Space name' => 'Название сообщества',
  'Space owner' => 'Владелец сообщества',
  'Stream (Default)' => 'Лента (по умолчанию)',
  'The URL has already been taken.' => 'URL-адрес уже использован.',
  'The url contains illegal characters!' => 'URL содержит недопустимые символы!',
  'This option will hide new content from this space at your dashboard' => 'Эта опция будет скрывать новый контент из этого сообщества на Вашей панели «События»',
  'This option will show new content from this space at your dashboard' => 'Эта опция будет отображать новый контент из этого сообщества на Вашей панели «События»',
  'Transfer ownership' => 'Передать другому владельцу',
  'Unarchive' => 'Разархивировать',
  'e.g. example for {baseUrl}/s/example' => 'например, для {baseUrl}/s/example',
  'never' => 'никогда',
);

==> humhub-1.16.2.tar.gz: humhub-1.16.2/protected/humhub/modules/space/messages/ru/manage.php <==
<?php
return array (
  '-' => '-',
  '<strong>Create</strong> Space' => '<strong>Создать</strong> новое сообщество',
  '<strong>Manage</strong> members' => '<strong>Управление</strong> пользователями',
  '<strong>Members</strong>' => '<strong>Участники</strong>',
  '<strong>Security</strong> settings' => '<strong>Настройки</strong> безопасности',
  '<strong>Space</strong> Modules' => '<strong>Модули</strong> сообщества',
  '<strong>Space</strong> settings' => '<strong>Настройки</strong> сообщества',
  'Actions' => 'Действия',
  'Add <strong>Modules</strong>' => '<strong>Добавить</strong> модули',
  'Advanced access settings' => 'Расширенные настройки доступа',
  'All members excluding moderators and administrators of this Space will be removed. All pending invitations and membership requests will be terminated.' => 'Все участники, за исключением модераторов и администраторов этого сообщества, будут удалены. Все ожидающие приглашения и запросы на членство будут аннулированы.',
  'Archive' => 'Архив',
  'Are you sure you want to remove this member.' => 'Вы уверены, что хотите удалить этого участника?',
  'Are you sure, that you want to delete this space? All published content will be removed!' => 'Вы уверены, что хотите удалить это сообщество? Все опубликованные материалы будут удалены!',
  'As owner of this space you can transfer this role to another administrator in space.' => 'Вы, как владелец этого сообщества, можете передать эту роль другому администратору в сообществе.',
  'Cancel Membership' => 'Отменить участие',
  'Choose if new content should be public or private by default' => 'Выберите, будет новый контент по умолчанию публичным или приватным',
  'Choose the kind of membership you want to provide for this workspace.' => 'Выберите вид членства, которое Вы хотите использовать для этого рабочего сообщества.',
  'Choose the modules you want to use for this Space. If you are undecided, you can also activate them later on via the Space settings.' => 'Выберите модули, которые вы хотите использовать для этого сообщества. Если вы не определились, вы также можете активировать их позже через настройки сообщества.',
  'Choose the modules you want to use for this Space. In order for the modules to be available to you here, they must have been previously installed by administrators of the network using the admin panel. If you cannot deactivate individual modules, it is because they have been set as the default for the entire network.' => 'Выберите модули, которые вы хотите использовать для этого сообщества. Для того, чтобы модули были доступны вам здесь, они должны быть предварительно установлены администраторами сети с помощью админ-панели. Если вы не можете деактивировать отдельные модули, это связано с тем, что они установлены по умолчанию для всей сети.',
  'Choose the security level for this workspace to define the visibleness.' => 'Выберите уровень безопасности для этого рабочего сообщества, чтобы определить его видимость.',
  'Currently there are no modules available for this space!' => 'В настоящее время нет доступных модулей для этого сообщества!',
  'Delete' => 'Удалить',
  'Don\'t receive notifications for new content' => 'Не получать уведомления о новом контенте',
  'Enable' => 'Активировать',
  'Hide posts on dashboard' => 'Скрывать записи',
  'Invited By' => 'Приглашён',
  'Members' => 'Участники',
  'Modules' => 'Модули',
  'Next' => 'Далее',
  'Only global administrators can change this value' => 'Только глобальные администраторы могут изменить это значение.',
  'Owner' => 'Владелец',
  'Pending Approvals' => 'Ожидающие подтверждения',
  'Pending Invites' => 'Ожидающие приглашения',
  'Permissions are assigned to different user-roles. To edit a permission, select the user-role you want to edit and change the drop-down value of the given permission.' => 'Права назначаются разным ролям пользователей. Чтобы редактировать права, выберите роль пользователя, которую Вы хотите редактировать, и измените его значение в раскрывающемся меню.',
  'Please type the name of the space to proceed.' => 'Пожалуйста, введите название сообщества, чтобы продолжить.',
  'Receive Notifications for new content' => 'Получать уведомления',
  'Removal of members queued' => 'Удаление участников из очереди',
  'Remove all members' => 'Удалить всех участников',
  'Remove from space' => 'Удалить из сообщества',
  'Role' => 'Роль',
  'Security' => 'Безопасность',
  'Show all' => 'Показать все',
  'Show posts on dashboard' => 'Показывать записи в панели «События»',
  'Space name' => 'Название сообщества',
  'Space owner' => 'Владелец сообщества',
  'Stream (Default)' => 'Лента (по умолчанию)',
  'The URL has already been taken.' => 'URL-адрес уже использован.',
  'The url contains illegal characters!' => 'URL содержит недопустимые символы!',
  'This option will hide new content from this space at your dashboard' => 'Эта опция будет скрывать новый контент из этого сообщества на Вашей панели «События»',
  'This option will show new content from this space at your dashboard' => 'Эта опция будет отображать новый контент из этого сообщества на Вашей панели «События»',
  'Transfer ownership' => 'Передать другому владельцу',
  'Unarchive' => 'Разархивировать',
  'e.g. example for {baseUrl}/s/example' => 'например: {baseUrl}/s/example',
  'never' => 'никогда',
);
